fauxmo\.plugins package
=======================

Submodules
----------

fauxmo\.plugins\.simplehttpplugin module
----------------------------------------

.. automodule:: fauxmo.plugins.simplehttpplugin
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: fauxmo.plugins
    :members:
    :undoc-members:
    :show-inheritance:
